@@ -7,7 +7,7 @@ use File::Basename;
 use Encode qw( encode decode_utf8 );
 use Mojo::Util 'quote';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub register {
     my ( $self, $app ) = @_;
@@ -25,8 +25,11 @@ sub register {
         my $cleanup             = $args{cleanup} // 0;
 
         # Content type based on format
-        my $content_type;
-        $content_type = $c->app->types->type( $args{format} ) if $args{format};
+		$c->app->log->error('You cannot provide both "format" and "content_type" option');
+        return if $args{format} && $args{content_type};
+
+        my $content_type = $args{content_type};
+        $content_type ||= $c->app->types->type( $args{format} ) if $args{format};
         $content_type ||= 'application/x-download';
 
         # Create asset
